@@ -21,7 +21,8 @@ rm -rf ${AUTO_DIR}/dorian-${VERSION}
 cp -Rf ${BUILD_DIR} ${AUTO_DIR}/dorian-${VERSION}
 cd ${AUTO_DIR}/dorian-${VERSION}
 mkdir debian
-cp pkg/changelog pkg/maemo/control pkg/maemo/rules debian
+cp pkg/changelog pkg/maemo/control pkg/maemo/rules pkg/maemo/postinst debian
+chmod a+rx debian/postinst
 echo "Version: $VERSION" >> debian/control
 echo "Installed-Size: "`du -c -k ${AUTO_DIR} | tail -1 | cut -f1` \
     >> debian/control
